# -*- coding: GBK -*-

from re import S

# regex_chapter_12 = {'': 'ʮ˽ļͶ.+(?<!)(?=ʮ)','ͨ':'ͶͶ[\S\s\t\n]+(?=ĲƲ)','ƽ':'ʮһͶ.+(?<!)(?=ʮ)',\
#         '':'ͶͶĿ.+ĲƲ','':'ʮһͶ.+(?<!)(?=ʮ)','':'ʮͶ.+(?<!)(?=ʮ)',\
#         '':'߽ Ͷ.+(?=ڰ˽)','':'(?<=)ʮһ˽ļͶ.+(?<!)(?=ʮ)','̩':'ʮһ˽ļͶ[\S\s\n]+(?<!)(?=ʮ)','㷢':'ʮһ Ͷ.+(?<!)(?=ʮ)'}

def get_chapter_regex(tg, beg_chapter_name, end_chapter_name):
        if tg=='̩' or tg=='' or tg=='' or tg=='' or tg=='' or tg=='ƽ' or tg=='' or tg=='㷢' or tg=='Ͷ' or tg=='': #done
                return r'(?<='+beg_chapter_name+r'[\S\s\n\t]+)'+beg_chapter_name+r'[\S\s\n\t]{10,}?(?='+end_chapter_name+')'
        if tg=='': #done
                return r'(?<=--	'+beg_chapter_name+')'+r'[\S\s\n\t]{10,}?(?=--	'+end_chapter_name+')'
        if tg=='ͨ': #done
                return r'(?<=--	'+beg_chapter_name+'--)'+r'[\S\s\n\t]{10,}?(?=--	'+end_chapter_name+')'
        if tg=='ҵ': #done
                return r'(?<=--(\t|	)'+beg_chapter_name+'--)'+r'[\S\s\n\t]{10,}?(?=--(\t|	)'+end_chapter_name+')'

def get_section_regex(tg, beg_section_name, end_section_name):
        if tg=='̩' or tg=='' or tg=='' or tg=='ƽ' or tg=='' or tg=='Ͷ' or tg=='': #done
                return r'(?<='+beg_section_name+r')[\S\s\t\n]+?(?=[\S\s\t\n]{,5}'+end_section_name+')'
        if tg=='': #done
                return r'(?<=[\S]{1,2}'+beg_section_name+r')[\S\s\t\n]+?(?=[\S]{1,2}'+end_section_name+')'
        if tg=='' or tg=='': #done
                return r'(?<=--	'+beg_section_name+r')[\S\s\n\t]+?(?=--	'+end_section_name+')'
        if tg=='ͨ': #done
                return r'(?<=--		'+beg_section_name+r')[\S\s\n\t]+?(?=--		'+end_section_name+')'
        if tg=='ҵ': #done
                return r'(?<=--(\t|	)'+beg_section_name+r')[\S\s\n\t]+?(?=--(\t|	)'+end_section_name+')'

def get_section_beg_end(tg, req_section):
        sections_dict = {'̩':['ͶĿ','ͶʷΧ','Ͷʲ','ҵȽϻ׼','Ͷ','ͶʽֹΪ'],
                         '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷʷʽ','ͶʱͶ','ͶʽֹΪ',''],
                         '':['ͶĿ','ͶʷΧ','Ͷ','׾Լ¶','ȫݶڴȨͬ','Ԥֹ','˽ļзشʩ','𱸰ǰֽ','ȯ','Ͷʾ'],
                         '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','Ͷʾָ','ҵȽϻ׼','տ','ڴ͸ԭԼ','ͶʽֹΪ','ʹƲͶ֤ȯȨԭ򼰷','',''],
                         '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','Ͷʾָͱ','տ','׼ͻ',''],
                         '':['ͶĿ','ͶʷΧ','ͶʷΧı','Ͷʲ','Ͷ','ֹΪ','ͻ','ȫݶڴȨͬ⣺','Ԥƽֻ','ʡȯ֤ȯҵ','йͶʼලΧ'],
                         '㷢':['Ʋı봦','Ʋ˻Ŀ͹', 'ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׼ͻμʽ','','Ԥֹ','ҵȽϻ׼','йͶʼලԼ'],
                         'ͨ':['Ͷʾ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','׵μʽ','','ҵȽϻ׼','ȯҵ֤ȯҵ','Ԥֹ'],
                         'ƽ':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','/','ͶʽֹΪ','Ԥֹտ','ҵȽϻ׼У','','Ͷߵı'],
                         '':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','ҵȽϻ׼У','סܴڵͻμʽ','ȯͶҵУ','Ԥ/ֹ','Ͷʾ','Ͷߵı','У'],
                         'ҵ':['ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','Ͷ˽ļ˹˽ļݶ˵','ߣȯ֤ȯҵ','','ȫݶڴȨͬ','','Ԥֹ','Ͷʾָ'],
                         '':['˿ɸ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','','','Ԥֹ','ҵȽϻ׼У','ýṹŵ',''],
                         'Ͷ':['Ͷʾ','ͶĿ','ͶʷΧ','Ͷʲ','Ͷ','ͶʽֹΪ','','׼ͻμʽ','','Ԥֹ','ҵȽϻ׼','йͶʼලԼ']}
        return [(section, sections_dict[tg][idx+1]) for idx, section in zip(range(len(sections_dict[tg])), sections_dict[tg]) if req_section in section]

def get_chapter_beg_end(tg, req_chapter):
        chapters_dict = {'̩':['һǰ  ',\
                                '  ',\
                                'ŵ',\
                                'ġ˽ļĻ',\
                                '塢˽ļļ',\
                                '˽ļĳͱ',\
                                'ߡ˽ļ깺ת',\
                                'ˡ˼Ȩ',\
                                'šݶ˴ἰճ',\
                                'ʮ˽ļݶעǼ',\
                                'ʮһ˽ļͶ',\
                                'ʮ˽ļĲƲ',\
                                'ʮ׼㽻հ',\
                                'ʮġ˽ļƲĹֵͻƺ',\
                                'ʮ塢˽ļķ˰',\
                                'ʮ˽ļ',\
                                'ʮߡϢ¶뱨',\
                                'ʮˡսʾ',\
                                'ʮšͬЧֹ',\
                                'ʮ˽ļ',\
                                'ʮһΥԼ',\
                                'ʮ鴦',\
                                'ʮ'],

                        '':['һǰ',\
                                '',\
                                'ŵ',\
                                'ġĻ',\
                                '塢ļ',\
                                'ĳ뱸',\
                                'ߡ깺ءתúת',\
                                'ˡ˼Ȩ',\
                                'šݶ˴ἰճ',\
                                'ʮݶĵǼ',\
                                'ʮһͶ',\
                                'ʮĲƲ',\
                                'ʮָķ͡ȷִ',\
                                'ʮġ׼㽻հ',\
                                'ʮ塢ԽȨ',\
                                'ʮƲĹֵͻƺ',\
                                'ʮߡķ˰',\
                                'ʮˡ',\
                                'ʮšϢ¶뱨',\
                                'ʮսʾ',\
                                'ʮһݶķǽ׹ͶᡢⶳѺ',\
                                'ʮͬĳЧǩ',\
                                'ʮͬЧ',\
                                'ʮġͬıֹ',\
                                'ʮ塢',\
                                'ʮΥԼ',\
                                'ʮߡ֪ͨʹ',\
                                'ʮˡúĴ',\
                                'ʮš',\
                                'ʮ'],

                        '':['Ҫʾ',\
                                'һǰ',\
                                '',\
                                'ŵ',\
                                'ġ˽ļĻ',\
                                '塢˽ļļ',\
                                '˽ļĳ뱸',\
                                'ߡ˽ļ깺غת',\
                                'ˡ˼Ȩ',\
                                'š˽ļݶ˴ἰճ',\
                                'ʮ˽ļݶĵǼ',\
                                'ʮһ˽ļͶ',\
                                'ʮ˽ļĲƲ',\
                                'ʮ׼㽻հ',\
                                'ʮġԽȨ״',\
                                'ʮ塢˽ļƲĹֵͻƺ',\
                                'ʮ˽ļķ˰',\
                                'ʮߡ˽ļ',\
                                'ʮˡϢ¶뱨',\
                                'ʮšսʾ',\
                                'ʮйļı',\
                                'ʮһͬЧֹ',\
                                'ʮ˽ļ',\
                                'ʮΥԼ',\
                                'ʮġúĴ',\
                                'ʮ塢',\
                                'һͶʼල',\
                                '˽ļ˽ļίеĻۻȨУ',\
                                'ͶϢ'],
                                
                        '':['ǰ',\
                                '',\
                                'ŵ',\
                                'Ļ',\
                                'ļ',\
                                'ĳͱ',\
                                '깺ת',\
                                '˼Ȩ',\
                                'ݶ˴ἰճ',\
                                'ݶĵǼ',\
                                'Ͷ',\
                                'ĲƲ',\
                                'ָķ͡ȷִ',\
                                '׼㽻հ',\
                                'ԽȨ',\
                                'ƲĹֵͻƺ',\
                                'ķ˰',\
                                '',\
                                'Ϣ¶뱨',\
                                'սʾ',\
                                'ݶķǽ׹Ͷ',\
                                'ͬǩ𡢳Ч',\
                                'ͬıֹ',\
                                '',\
                                'ΥԼΡ׽ά',\
                                '֪ͨʹ',\
                                '',\
                                'Ͷ߼Ϣдҳ',\
                                'һͶʼල'],
                        
                        '':['һ ǰ',\
                                'ڶ ',\
                                ' ŵ',\
                                'Ľ Ļ',\
                                ' ݶĳʼ',\
                                ' ĳ뱸',\
                                '߽ Ͷ',\
                                'ڰ˽ ݶ깺',\
                                'ھŽ Ͷ侲ڼطȷ',\
                                'ʮ ˼Ȩ',\
                                'ʮһ ݶ˴',\
                                'ʮ ݶĵǼǡתúͷǽ׹',\
                                'ʮ ĲƲ',\
                                'ʮĽ ָķ͡ȷִ',\
                                'ʮ ׼㽻հ',\
                                'ʮ й˵ļලְ',\
                                'ʮ߽ ƲĹֵͻƺ',\
                                'ʮ˽ ķ˰',\
                                'ʮŽ ',\
                                'ڶʮ Ϣ¶뱨',\
                                'ڶʮһ սʾ',\
                                'ڶʮ ͬޡֹ',\
                                'ڶʮ Ʋ',\
                                'ڶʮĽ ΥԼ',\
                                'ڶʮ Ĵ',\
                                'ڶʮ '],

                        '':['һͬ',\
                                'ǰ',\
                                '',\
                                'ġŵ',\
                                '塢Ļ',\
                                'ݶļ',\
                                'ߡĳ뱸',\
                                'ˡ깺ؼת',\
                                'š˵Ȩ',\
                                'ʮݶ˴ἰճ',\
                                'ʮһݶĵǼ',\
                                'ʮͶ',\
                                'ʮͶʾָ',\
                                'ʮġĲƲ',\
                                'ʮ塢ָķ͡ȷϺִ',\
                                'ʮʽ㽻հ',\
                                'ʮߡԽȨ״',\
                                'ʮˡʲĹֵͻƺ',\
                                'ʮšķ˰',\
                                'ʮ',\
                                'ʮһϢ¶',\
                                'ʮսʾ',\
                                'ʮͬıֹƲ',\
                                'ʮġΥԼ',\
                                'ʮ塢Ĵ',\
                                'ʮͬЧ',\
                                'ʮߡ'],
                                
                        '㷢':['һ ǰ',\
                                ' ',\
                                ' ŵ',\
                                'ġ Ļ',\
                                '塢 ݶļ',\
                                ' ĳ뱸',\
                                'ߡ 깺غת',\
                                'ˡ ˼Ȩ',\
                                'š ݶ˴ἰճ',\
                                'ʮ ݶĵǼ',\
                                'ʮһ Ͷ',\
                                'ʮ ĲƲ',\
                                'ʮ ָķ͡ȷִ',\
                                'ʮġ ׼㽻հ',\
                                'ʮ塢 ԽȨ',\
                                'ʮ ƲĹֵͻƺ',\
                                'ʮߡ ķ˰',\
                                'ʮˡ ',\
                                'ʮš Ϣ¶뱨',\
                                'ʮ սʾ',\
                                'ʮһ ݶķǽ׹Ͷᡢⶳ',\
                                'ʮ ͬЧֹ',\
                                'ʮ ',\
                                'ʮġ ΥԼ',\
                                'ʮ塢 úĴ',\
                                'ʮ '],
                                
                        'ͨ':['Ҫʾ',\
                                'սʾ',\
                                'ϸͶ߳ŵ',\
                                'Ͷ߸֪',\
                                'ǰ',\
                                '',\
                                'ŵ',\
                                'Ļ',\
                                'ݶļ',\
                                'ĳ뱸',\
                                '깺غת',\
                                '˼Ȩ',\
                                'ݶ˴ἰճ',\
                                'ݶĵǼ',\
                                'Ͷ',\
                                'ĲƲ',\
                                'ָķ͡ȷִ',\
                                'ʮġ ׼㽻հ',\
                                'ʮ塢 ԽȨ',\
                                'ʮ ƲĹֵͻƺ',\
                                'ʮߡ ķ˰',\
                                'ʮˡ ',\
                                'ʮš Ϣ¶뱨',\
                                'ʮ ݶķǽ׹Ͷᡢⶳ',\
                                'ʮһ ͬĳЧ',\
                                'ʮ ͬЧֹ',\
                                'ʮ ',\
                                'ʮġ ΥԼ',\
                                'ʮ塢 úĴ',\
                                'ʮ '],

                        'ƽ':['һǰ',\
                                '',\
                                'ŵ',\
                                'ġĻ',\
                                '塢˽ļļ',\
                                '˽ļĳ뱸',\
                                'ߡ깺ת',\
                                'ˡ˼Ȩ',\
                                'šݶ˴ἰճ',\
                                'ʮݶĵǼ',\
                                'ʮһͶ',\
                                'ʮͶʾָ',\
                                'ʮĲƲ',\
                                'ʮġָķ͡ȷִ',\
                                'ʮ塢׼㽻հ',\
                                'ʮԽȨ',\
                                'ʮߡƲĹֵͻƺ',\
                                'ʮˡķ˰',\
                                'ʮš',\
                                'ʮϢ¶뱨',\
                                'ʮһսʾ',\
                                'ʮͬЧֹ',\
                                'ʮ',\
                                'ʮġΥԼ',\
                                'ʮ塢',\
                                'ʮϴǮֲʺͷ˰',\
                                'ʮߡúĴ',\
                                'ʮˡ֪ͨʹ',\
                                'ʮš'],

                        '':['Ҫʾ',\
                                'սʾ',\
                                'ϸͶ߳ŵ',\
                                'Ͷ߸֪',\
                                'Ŀ¼',\
                                'һǰ',\
                                '',\
                                'ŵ',\
                                'ġĻ',\
                                '塢ļ',\
                                'ĳ뱸',\
                                'ߡ깺',\
                                'ˡ˼Ȩ',\
                                'šݶ˴',\
                                'ʮݶĵǼ',\
                                'ʮһݶתáǽ׹Ͷᡢⶳ',\
                                'ʮͶ',\
                                'ʮĲƲ',\
                                'ʮġ׼㽻հ',\
                                'ʮ塢ָķ͡ȷִ',\
                                'ʮԽȨ״',\
                                'ʮߡƲĹֵ;ֵ',\
                                'ʮˡķ˰',\
                                'ʮš',\
                                'ʮϢ¶',\
                                'ʮһйļı',\
                                'ʮ˽ļй˺˽ļ˵ĸ',\
                                'ʮսʾ',\
                                'ʮġͬЧֹ',\
                                'ʮ塢',\
                                'ʮΥԼ',\
                                'ʮߡúĴ',\
                                'ʮˡ֪ͨʹ',\
                                'ʮš'],

                        'ҵ':['սʾ',\
                                'ǰ',\
                                '',\
                                'ŵ',\
                                '˽ļĻ',\
                                '˽ļļ',\
                                '˽ļĳ뱸',\
                                '˽ļ깺ת',\
                                '˼Ȩ',\
                                '˽ļݶ˴ἰճ',\
                                '˽ļݶĵǼ',\
                                '˽ļͶ',\
                                '˽ļĲƲ',\
                                '׼㽻հ',\
                                'ԽȨ',\
                                '˽ļƲĹֵͻƺ',\
                                '˽ļķ˰',\
                                '˽ļĲƲ',\
                                'Ϣ¶뱨',\
                                'սʾ',\
                                '˽ļݶĶᡢⶳ',\
                                'ͬЧֹ',\
                                '˽ļ',\
                                'ΥԼ',\
                                'úĴ',\
                                ''],

                        'Ͷ':['Ҫʾ',\
                                'ŻƱ8˽ļ֤ȯͶʻսʾ',\
                                'ϸͶ߳ŵ',\
                                'Ͷ߸֪',\
                                'һǰ',\
                                '',\
                                'ŵ',\
                                'ġ˽ļĻ',\
                                '塢˽ļĽṹ',\
                                '˽ļļ',\
                                'ߡ˽ļĳ뱸',\
                                'ˡ˽ļ깺غת',\
                                'š˵Ȩ',\
                                'ʮݶ˴ἰճ',\
                                'ʮһ˽ļݶĵǼ',\
                                'ʮ˽ļͶ',\
                                'ʮ˽ļĲƲ',\
                                'ʮġʽ㽻հ',\
                                'ʮ塢Ͷָķ͡ȷϺִ',\
                                'ʮ˽ļʲĹֵͻƺ',\
                                'ʮߡ˽ļķ˰',\
                                'ʮˡ˽ļ',\
                                'ʮšϢ¶뱨',\
                                'ʮսʾ',\
                                'ʮһ˽ļͬЧֹ',\
                                'ʮ˽ļ',\
                                'ʮΥԼ',\
                                'ʮġĴ',\
                                'ʮ塢ά',\
                                'ʮ'],
                        
                        '':['һǰ',\
                                '',\
                                'ŵ',\
                                'ġ˽ļĻ',\
                                '塢˽ļļ',\
                                '˽ļĳ뱸',\
                                'ߡ˽ļݶ깺ת',\
                                'ˡ˼Ȩ',\
                                'šݶ˴ἰճ',\
                                'ʮ˽ļݶĵǼ',\
                                'ʮһ˽ļͶ',\
                                'ʮ˽ļĲƲ',\
                                'ʮָķ͡ȷִ',\
                                'ʮġ׼㽻հ',\
                                'ʮ塢˽ļƲĹֵƺ',\
                                'ʮ˽ļķ˰',\
                                'ʮߡ˽ļ',\
                                'ʮˡ˽ļϢ¶뱨',\
                                'ʮšսʾ',\
                                'ʮݶķǽ׹ᡢⶳѺ',\
                                'ʮһͬĳЧǩ',\
                                'ʮͬЧ',\
                                'ʮͬıֹ',\
                                'ʮġ˽ļ',\
                                'ʮ塢ΥԼ',\
                                'ʮ֪ͨʹ',\
                                'ʮߡúĴ',\
                                'ʮˡ']}
        return [(chapter, chapters_dict[tg][idx+1]) for idx, chapter in zip(range(len(chapters_dict[tg])), chapters_dict[tg]) if req_chapter in chapter]